==> data-weave-maven-plugin-0.3.0-sources.jar: org/mule/weave/maven/plugin/AbstractWeaveMojo.java <==
package org.mule.weave.maven.plugin;

import org.apache.maven.execution.MavenSession;
import org.apache.maven.model.DeploymentRepository;
import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugins.annotations.Parameter;
import org.apache.maven.project.MavenProject;

import java.io.File;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public abstract class AbstractWeaveMojo extends AbstractMojo {

    /**
     * The maven project
     */
    @Parameter(property = "project", required = true, readonly = true)
    protected MavenProject project;

    @Parameter(defaultValue = "${session}", required = true, readonly = true)
    protected MavenSession session;
    
    /**
     * The directory where the DataWeave files are going to be located
     */
    @Parameter(defaultValue = "${project.basedir}/src/main/dw", required = true, readonly = true)
    protected File sourceFolder;

    @Parameter(defaultValue = "${project.basedir}/src/test/dw", required = true, readonly = true)
    protected File dwTestFolder;

    @Parameter(defaultValue = "${project.basedir}/src/test/resources", required = true, readonly = true)
    protected File dwTestResources;


    /**
     * Deployment settings
     */
    @Parameter( property = "altDeploymentRepository" )
    private String altDeploymentRepository;

    private static final Pattern ALT_LEGACY_REPO_SYNTAX_PATTERN = Pattern.compile( "(.+?)::(.+?)::(.+)" );
    private static final Pattern ALT_REPO_SYNTAX_PATTERN = Pattern.compile( "(.+?)::(.+)" );

    DeploymentRepository getDeploymentRepository() throws MojoFailureException {
        if ( altDeploymentRepository != null ) {
            getLog().info( "Using alternate deployment repository " + altDeploymentRepository );

            Matcher matcher = ALT_LEGACY_REPO_SYNTAX_PATTERN.matcher( altDeploymentRepository );

            if ( matcher.matches() ) {
                String id = matcher.group( 1 ).trim();
                String layout = matcher.group( 2 ).trim();
                String url = matcher.group( 3 ).trim();

                if ( "default".equals( layout ) ) {
                    getLog().warn( "Using legacy syntax for alternative repository. "
                            + "Use \"" + id + "::" + url + "\" instead." );

                    DeploymentRepository deploymentRepository = new DeploymentRepository();
                    deploymentRepository.setId(id);
                    deploymentRepository.setUrl(url);
                    deploymentRepository.setLayout(layout);
                    return deploymentRepository;
                } else {
                    throw new MojoFailureException( altDeploymentRepository,
                            "Invalid legacy syntax and layout for repository.",
                            "Invalid legacy syntax and layout for alternative repository. Use \""
                                    + id + "::" + url + "\" instead, and only default layout is supported."
                    );
                }
            } else {
                matcher = ALT_REPO_SYNTAX_PATTERN.matcher( altDeploymentRepository );

                if ( !matcher.matches() ) {
                    throw new MojoFailureException( altDeploymentRepository,
                            "Invalid syntax for repository.",
                            "Invalid syntax for alternative repository. Use \"id::url\"."
                    );
                } else {
                    String id = matcher.group( 1 ).trim();
                    String url = matcher.group( 2 ).trim();

                    DeploymentRepository deploymentRepository = new DeploymentRepository();
                    deploymentRepository.setId(id);
                    deploymentRepository.setUrl(url);
                    return deploymentRepository;

                }
            }
        }

        return project.getDistributionManagement().getRepository();
    }
}

==> data-weave-maven-plugin-2.7.0-sources.jar: org/mule/weave/maven/plugin/AbstractWeaveMojo.java <==
package org.mule.weave.maven.plugin;

import org.apache.maven.artifact.DependencyResolutionRequiredException;
import org.apache.maven.execution.MavenSession;
import org.apache.maven.model.DeploymentRepository;
import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugins.annotations.Parameter;
import org.apache.maven.project.MavenProject;

import java.io.File;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public abstract class AbstractWeaveMojo extends AbstractMojo {

    /**
     * The maven project
     */
    @Parameter(property = "project", required = true, readonly = true)
    protected MavenProject project;

    @Parameter(defaultValue = "${session}", required = true, readonly = true)
    protected MavenSession session;
    
    /**
     * The directory where the DataWeave files are going to be located
     */
    @Parameter(defaultValue = "${project.basedir}/src/main/dw", required = true, readonly = true)
    protected File sourceFolder;

    @Parameter(defaultValue = "${project.basedir}/src/test/dw", required = true, readonly = true)
    protected File dwTestFolder;

    @Parameter(defaultValue = "${project.basedir}/src/test/resources", required = true, readonly = true)
    protected File dwTestResources;


    /**
     * Deployment settings
     */
    @Parameter( property = "altDeploymentRepository" )
    private String altDeploymentRepository;

    private static final Pattern ALT_LEGACY_REPO_SYNTAX_PATTERN = Pattern.compile( "(.+?)::(.+?)::(.+)" );
    private static final Pattern ALT_REPO_SYNTAX_PATTERN = Pattern.compile( "(.+?)::(.+)" );


    protected String buildTestClassPathEnvironment() {
        StringBuffer buffer = new StringBuffer();
        boolean first = true;
        for (String e : testClasspathElements()) {
            if (first) {
                first = false;
            } else {
                buffer.append(File.pathSeparator);
            }
            buffer.append(e);
        }
        return buffer.toString();
    }

    // Have to use the programmatic way of getting the classpath elements
    // instead of the field-level injection since that apparently doesn't work
    // for ReporterMojos in maven-2.2 (it does work in maven-3)
    protected List<String> compileClasspathElements() {
        try {
            return project.getCompileClasspathElements();
        } catch (DependencyResolutionRequiredException e) {
            // There's really no known way this exception can happen since
            // the @requiresDependencyResolution at the top of the class
            // defines test-scoped resolution.
            throw new IllegalStateException("Dependency resolution should be test-scoped.", e);
        }
    }

    // Have to use the programmatic way of getting the classpath elements
    // instead of the field-level injection since that apparently doesn't work
    // for ReporterMojos in maven-2.2 (it does work in maven-3)
    protected List<String> testClasspathElements() {
        try {
            return project.getTestClasspathElements();
        } catch (DependencyResolutionRequiredException e) {
            // There's really no known way this exception can happen since
            // the @requiresDependencyResolution at the top of the class
            // defines test-scoped resolution.
            throw new IllegalStateException("Dependency resolution should be test-scoped.", e);
        }
    }

    protected DeploymentRepository getDeploymentRepository() throws MojoFailureException {
        if ( altDeploymentRepository != null ) {
            getLog().info( "Using alternate deployment repository " + altDeploymentRepository );

            Matcher matcher = ALT_LEGACY_REPO_SYNTAX_PATTERN.matcher( altDeploymentRepository );

            if ( matcher.matches() ) {
                String id = matcher.group( 1 ).trim();
                String layout = matcher.group( 2 ).trim();
                String url = matcher.group( 3 ).trim();

                if ( "default".equals( layout ) ) {
                    getLog().warn( "Using legacy syntax for alternative repository. "
                            + "Use \"" + id + "::" + url + "\" instead." );

                    DeploymentRepository deploymentRepository = new DeploymentRepository();
                    deploymentRepository.setId(id);
                    deploymentRepository.setUrl(url);
                    deploymentRepository.setLayout(layout);
                    return deploymentRepository;
                } else {
                    throw new MojoFailureException( altDeploymentRepository,
                            "Invalid legacy syntax and layout for repository.",
                            "Invalid legacy syntax and layout for alternative repository. Use \""
                                    + id + "::" + url + "\" instead, and only default layout is supported."
                    );
                }
            } else {
                matcher = ALT_REPO_SYNTAX_PATTERN.matcher( altDeploymentRepository );

                if ( !matcher.matches() ) {
                    throw new MojoFailureException( altDeploymentRepository,
                            "Invalid syntax for repository.",
                            "Invalid syntax for alternative repository. Use \"id::url\"."
                    );
                } else {
                    String id = matcher.group( 1 ).trim();
                    String url = matcher.group( 2 ).trim();

                    DeploymentRepository deploymentRepository = new DeploymentRepository();
                    deploymentRepository.setId(id);
                    deploymentRepository.setUrl(url);
                    return deploymentRepository;

                }
            }
        }

        return project.getDistributionManagement().getRepository();
    }
}
